@@ -49,18 +49,19 @@ if 'linux' in sys.platform:
 from tails_installer.utils import (_move_if_exists, _unlink_if_exists, unicode_to_utf8,
                            unicode_to_filesystemencoding, is_running_from_tails,
                            _set_liberal_perms_recursive, underlying_physical_device,
-                           get_open_write_fd, write_to_block_device)
+                           get_open_write_fd, write_to_block_device,
+                           MiB_to_bytes)
 from tails_installer import _
 from tails_installer.config import config
 from tails_installer.source import SourceError
 
 #XXX: size should be configurable
-SYSTEM_PARTITION_FLAGS = [ 0,    # system partition
-                           2,    # legacy BIOS bootable
-                           60,   # read-only
-                           62,   # hidden
-                           63    # do not automount
-                         ]
+SYSTEM_PARTITION_FLAGS = [0,    # system partition
+                          2,    # legacy BIOS bootable
+                          60,   # read-only
+                          62,   # hidden
+                          63    # do not automount
+                          ]
 # EFI System Partition
 ESP_GUID = 'C12A7328-F81F-11D2-BA4B-00A0C93EC93B'
 
@@ -71,8 +72,7 @@ class TailsInstallerError(Exception):
 class TailsInstallerCreator(object):
     """ An OS-independent parent class for Tails Installer Creators """
 
-    system_partition_size = config['min_system_partition_size'] # MiB
-    min_persistence_partition_size = config['min_persistence_partition_size'] # MiB
+    min_installation_device_size = config['min_installation_device_size'] # MiB
     source = None       # the object representing our live source image
     label = config['branding']['partition_label'] # if one doesn't already exist
     fstype = None       # the format of our usb stick
@@ -88,9 +88,10 @@ class TailsInstallerCreator(object):
     log = None
     ext_fstypes = set(['ext2', 'ext3', 'ext4'])
     valid_fstypes = set(['vfat', 'msdos']) | ext_fstypes
+    force_reinstall = False
 
     drive = property(fget=lambda self: self.drives[self._drive],
-	                     fset=lambda self, d: self._set_drive(d))
+                     fset=lambda self, d: self._set_drive(d))
 
     def __init__(self, opts):
         self.opts = opts
@@ -150,7 +151,8 @@ class TailsInstallerCreator(object):
         if delta.seconds:
             self.mb_per_sec = (self.source.size / delta.seconds) / 1024**2
             if self.mb_per_sec:
-                self.log.info(_("Wrote to device at %(speed)d MB/sec") % {'speed': self.mb_per_sec})
+                self.log.info(_("Wrote to device at %(speed)d MB/sec") % {
+                    'speed': self.mb_per_sec})
 
     def syslinux_options(self):
         opts = []
@@ -165,29 +167,9 @@ class TailsInstallerCreator(object):
 
         Platform-specific classes inheriting from the TailsInstallerCreator are
         expected to implement this method to install the bootloader to the
-        specified device using syslinux.  This specific implemention is
-        platform independent and performs sanity checking along with adding
-        OLPC support.
+        specified device using syslinux.
         """
-        if self.opts.xo:
-            self.setup_olpc()
-
-    def setup_olpc(self):
-        """ Install the Open Firmware configuration for the OLPC.
-
-        This method will make the selected device bootable on the OLPC.  It
-        does this by installing a /boot/olpc.fth open firmware configuration
-        file that enables booting off of USB and SD cards on the XO.
-        """
-        from tails_installer.olpc import ofw_config
-        self.log.info(_('Setting up OLPC boot file...'))
-        args = self.get_kernel_args()
-        if not os.path.exists(self.get_liveos_file_path('boot')):
-            os.mkdir(self.get_liveos_file_path('boot'))
-        olpc_cfg = file(self.get_liveos_file_path('boot', 'olpc.fth'), 'w')
-        olpc_cfg.write(ofw_config % ' '.join(args))
-        olpc_cfg.close()
-        self.log.debug('Wrote %s' % olpc_cfg.name)
+        return
 
     def get_kernel_args(self):
         """ Grab the kernel arguments from our syslinux configuration """
@@ -225,23 +207,36 @@ class TailsInstallerCreator(object):
         """ Partition device listed at self.drive """
         raise NotImplementedError
 
-    def update_system_partition_properties(self):
-        cmd = (  [ '/sbin/sgdisk' ]
-               + [ '--typecode=1:%s' % ESP_GUID ]
-               + [ self.drive['parent'] ])
-        self.popen(cmd, shell=False)
+    def system_partition_size(self, device_size_in_bytes):
+        """ Return the optimal system partition size (in bytes) for
+        a device_size_in_bytes bytes large destination device: 4 GiB on devices
+        smaller than 16000 MiB, 8 GiB otherwise.
+        """
+        # 1. Get unsupported cases out of the way
+        if device_size_in_bytes \
+           < MiB_to_bytes(self.min_installation_device_size):
+            raise NotImplementedError
+        # 2. Handle supported cases (note: you might be surprised if
+        # you looked at the actual size of USB sticks labeled "16 GB"
+        # in the real world, hence the weird definition of "16 GB"
+        # used below)
+        elif device_size_in_bytes >= MiB_to_bytes(14500):
+            return MiB_to_bytes(8 * 1024)
+        else:
+            return MiB_to_bytes(4 * 1024)
 
-    def is_device_big_enough(self, deviceSize):
-        if (self.system_partition_size + self.min_persistence_partition_size) \
-                * 1024**2 <= deviceSize:
-            return True
-        return False
+    def is_device_big_enough_for_installation(self, device_size_in_bytes):
+        return (
+            device_size_in_bytes
+            >= MiB_to_bytes(self.min_installation_device_size)
+        )
 
     def can_read_partition_table(self, device=None):
         if not device:
             device = self.drive['device']
 
-        proc = self.popen(['/sbin/sgdisk', '--print', device], shell=False, passive=True)
+        proc = self.popen(['/sbin/sgdisk', '--print', device],
+                          shell=False, passive=True)
         if proc.returncode:
             return False
         return True
@@ -277,13 +272,13 @@ class TailsInstallerCreator(object):
         """
         if isinstance(cmd, list):
             cmd_decoded = u' '.join(cmd)
-            cmd_bytes = [ unicode_to_filesystemencoding(el) for el in cmd ]
+            cmd_bytes = [unicode_to_filesystemencoding(el) for el in cmd]
         else:
             cmd_decoded = cmd
             cmd_bytes = unicode_to_filesystemencoding(cmd)
         self.log.debug(cmd_decoded)
         self.output.write(cmd_bytes)
-        kwargs = { 'shell': True, 'stdin': subprocess.PIPE }
+        kwargs = {'shell': True, 'stdin': subprocess.PIPE}
         kwargs.update(user_kwargs)
         proc = subprocess.Popen(cmd_bytes, stdout=subprocess.PIPE,
                                 stderr=subprocess.PIPE,
@@ -355,10 +350,11 @@ class TailsInstallerCreator(object):
         self.log.debug('overlaysize = %d' % overlaysize)
         self.totalsize = overlaysize + self.source.size
         if self.totalsize > freebytes:
-            raise TailsInstallerError(_("Not enough free space on device." +
-                                 "\n%dMB ISO + %dMB overlay > %dMB free space") %
-                                 (self.source.size/1024**2, self.overlay,
-                                  freebytes/1024**2))
+            raise TailsInstallerError(_(
+                "Not enough free space on device." +
+                "\n%dMB ISO + %dMB overlay > %dMB free space") %
+                (self.source.size/1024**2, self.overlay,
+                 freebytes/1024**2))
 
     def create_persistent_overlay(self):
         if self.overlay:
@@ -450,9 +446,10 @@ class TailsInstallerCreator(object):
                 try:
                     os.unlink(path)
                 except:
-                    raise TailsInstallerError(_("Unable to remove file from"
-                                         " previous LiveOS: %(message)s")
-                                         % {'message': str(e)})
+                    raise TailsInstallerError(_(
+                        "Unable to remove file from"
+                        " previous LiveOS: %(message)s")
+                        % {'message': str(e)})
             elif os.path.isdir(path):
                 try:
                     _set_liberal_perms_recursive(path)
@@ -462,9 +459,10 @@ class TailsInstallerCreator(object):
                 try:
                     shutil.rmtree(path)
                 except OSError, e:
-                    raise TailsInstallerError(_("Unable to remove directory from"
-                                         " previous LiveOS: %(message)s")
-                                         % {'message': str(e)})
+                    raise TailsInstallerError(_(
+                        "Unable to remove directory from"
+                        " previous LiveOS: %(message)s")
+                        % {'message': str(e)})
 
     def get_liveos(self):
         return self.get_liveos_file_path(config['main_liveos_dir'])
@@ -488,7 +486,7 @@ class TailsInstallerCreator(object):
         """
         toplevels = config['liveos_toplevel_files']
         if absolute:
-            return [ self.get_liveos_file_path(f) for f in toplevels ]
+            return [self.get_liveos_file_path(f) for f in toplevels]
         return toplevels
 
     def existing_overlay(self):
@@ -582,13 +580,15 @@ class LinuxTailsInstallerCreator(TailsInstallerCreator):
             block = obj.props.block
             self.log.debug("looking at %s" % obj.get_object_path())
             if not block:
-                self.log.debug("skip %s which is not a block device" % obj.get_object_path())
+                self.log.debug("skip %s which is not a block device"
+                               % obj.get_object_path())
                 continue
             partition = obj.props.partition
             filesystem = obj.props.filesystem
             drive = self._udisksclient.get_drive_for_block(block)
             if not drive:
-                self.log.debug("skip %s which has no associated drive" % obj.get_object_path())
+                self.log.debug("skip %s which has no associated drive"
+                               % obj.get_object_path())
                 continue
             data = {
                 'udi': obj.get_object_path(),
@@ -605,19 +605,22 @@ class LinuxTailsInstallerCreator(TailsInstallerCreator):
                 'parent': None,
                 'parent_udi': None,
                 'parent_size': None,
-                'size': drive.props.size,
+                'size': block.props.size,
                 'mounted_partitions': set(),
-                'is_device_big_enough': True,
+                'is_device_big_enough_for_installation': True,
+                'is_device_big_enough_for_upgrade': True,
                 'removable': drive.props.removable,
             }
 
             # Check non-removable drives
             if not data['removable']:
-                self.log.debug('Skipping non-removable device: %s' % data['device'])
+                self.log.debug('Skipping non-removable device: %s'
+                               % data['device'])
 
             # Only pay attention to USB and SDIO devices, unless --force'd
             iface = drive.props.connection_bus
-            if iface != 'usb' and iface != 'sdio' and self.opts.force != data['device']:
+            if iface != 'usb' and iface != 'sdio' \
+               and self.opts.force != data['device']:
                 self.log.warning(
                     "Skipping device '%(device)s' connected to '%(interface)s' interface"
                     % {'device': data['udi'], 'interface': iface}
@@ -631,11 +634,13 @@ class LinuxTailsInstallerCreator(TailsInstallerCreator):
 
             # Skip things without a size
             if not data['size'] and not self.opts.force:
-                self.log.debug('Skipping device without size: %s' % data['device'])
+                self.log.debug('Skipping device without size: %s'
+                               % data['device'])
                 continue
 
             if partition:
-                partition_table = self._udisksclient.get_partition_table(partition)
+                partition_table = self._udisksclient.get_partition_table(
+                    partition)
                 parent_block = partition_table.get_object().props.block
                 data['label'] = partition.props.name
                 data['parent'] = parent_block.props.device
@@ -644,17 +649,38 @@ class LinuxTailsInstallerCreator(TailsInstallerCreator):
             else:
                 parent_block = None
 
-            # Check for devices that are too small
-            if self.opts.partition and not parent_block \
-                  and not self.is_device_big_enough(data['size']):
-                self.log.warning('Skipping too small device: %s' % data['device'])
-                data['is_device_big_enough'] = False
+            # Check for devices that are too small. Note that we still
+            # allow devices that can be upgraded for supporting legacy
+            # installations.
+            if not self.is_device_big_enough_for_installation(
+                    data['parent_size']
+                    if data['parent_size']
+                    else data['size']) \
+               and not self.device_can_be_upgraded(data):
+                self.log.warning(
+                    'Device is too small for installation: %s'
+                    % data['device'])
+                data['is_device_big_enough_for_installation'] = False
+
+            # To be more accurate we would need to either mount the candidate
+            # device (which causes UX problems down the road) or to recursively
+            # parse the output of fatcat.
+            # We add a 5% margin to account for filesystem structures.
+            if partition \
+               and self.device_can_be_upgraded(data) \
+               and hasattr(self, 'source') \
+               and self.source is not None \
+               and data['size'] < self.source.size * 1.05:
+                self.log.warning(
+                    'Device is too small for upgrade: %s'
+                    % data['device'])
+                data['is_device_big_enough_for_upgrade'] = False
 
             mount = data['mount']
             if mount:
                 if len(mount) > 1:
                     self.log.warning('Multiple mount points for %s' %
-                            data['device'])
+                                     data['device'])
                 mount = data['mount'] = data['mount'][0]
             else:
                 mount = data['mount'] = None
@@ -671,8 +697,10 @@ class LinuxTailsInstallerCreator(TailsInstallerCreator):
             self.log.debug(pformat(data))
 
             if not force_partitions and self.opts.partition:
+                if self.device_can_be_upgraded(data):
+                    self.drives[data['device']] = data
                 # Add whole drive in partitioning mode
-                if data['parent'] is None:
+                elif data['parent'] is None:
                     # Ensure the device is writable
                     if block.props.read_only:
                         self.log.debug(_('Unable to write on %(device)s, skipping.')
@@ -680,23 +708,30 @@ class LinuxTailsInstallerCreator(TailsInstallerCreator):
                         continue
                     self.drives[data['device']] = data
             else:
-               self.drives[data['device']] = data
+                if self.device_is_isohybrid(data):
+                    if data['parent']:
+                        # We will target the parent instead
+                        continue
+                self.drives[data['device']] = data
 
-               # Remove parent drives if a valid partition exists
-               for parent in [d['parent'] for d in self.drives.values()]:
-                   if parent in self.drives:
+            # Remove parent drives if a valid partition exists
+            if not self.force_reinstall:
+                for parent in [d['parent'] for d in self.drives.values()]:
+                    if parent in self.drives:
                         del(self.drives[parent])
 
         self.log.debug(pformat(mounted_parts))
 
         for device, data in self.drives.iteritems():
-            if self.source and self.source.dev and data['udi'] == self.source.dev:
+            if self.source \
+               and self.source.dev and data['udi'] == self.source.dev:
                 continue
             if device in mounted_parts and len(mounted_parts[device]) > 0:
                 data['mounted_partitions'] = mounted_parts[device]
-                self.log.debug(_('Some partitions of the target device %(device)s are mounted. '
-                                 'They will be unmounted before starting the '
-                                 'installation process.') % {'device': data['device']})
+                self.log.debug(_(
+                    'Some partitions of the target device %(device)s are mounted. '
+                    'They will be unmounted before starting the '
+                    'installation process.') % {'device': data['device']})
 
         if callback:
             callback()
@@ -723,25 +758,25 @@ class LinuxTailsInstallerCreator(TailsInstallerCreator):
         if parent:
             parent = parent.GetProperty('block.device')
         self.drives[device] = {
-            'label'   : str(dev.GetProperty('volume.label')).replace(' ', '_'),
-            'fstype'  : str(dev.GetProperty('volume.fstype')),
+            'label':     str(dev.GetProperty('volume.label')).replace(' ', '_'),
+            'fstype':    str(dev.GetProperty('volume.fstype')),
             'fsversion': str(dev.GetProperty('volume.fsversion')),
-            'uuid'    : str(dev.GetProperty('volume.uuid')),
-            'mount'   : mount,
-            'udi'     : dev,
-            'free'    : mount and self.get_free_bytes(mount) / 1024**2 or None,
-            'device'  : device,
-            'parent'  : parent
+            'uuid':      str(dev.GetProperty('volume.uuid')),
+            'mount':     mount,
+            'udi':       dev,
+            'free':      mount and self.get_free_bytes(mount) / 1024**2 or None,
+            'device':    device,
+            'parent':    parent
         }
 
     def mount_device(self):
         """ Mount our device if it is not already mounted """
         if not self.fstype:
             raise TailsInstallerError(_("Unknown filesystem.  Your device "
-                                 "may need to be reformatted."))
+                                        "may need to be reformatted."))
         if self.fstype not in self.valid_fstypes:
             raise TailsInstallerError(_("Unsupported filesystem: %s") %
-                                 self.fstype)
+                                      self.fstype)
         self.dest = self.drive['mount']
         if not self.dest:
             self.log.debug("Mounting %s" % self.drive['udi'])
@@ -751,18 +786,20 @@ class LinuxTailsInstallerCreator(TailsInstallerCreator):
             mount = None
             try:
                 mount = filesystem.call_mount_sync(
-                        arg_options = GLib.Variant('a{sv}', None),
-                        cancellable = None)
+                    arg_options=GLib.Variant('a{sv}', None),
+                    cancellable=None)
             except GLib.Error as e:
                 if 'org.freedesktop.UDisks2.Error.AlreadyMounted' in e.message:
                     self.log.debug('Device already mounted')
                 else:
-                    raise TailsInstallerError(_('Unknown GLib exception while trying to '
-                                     'mount device: %(message)s')
-                                     % {'message': str(e)})
+                    raise TailsInstallerError(_(
+                        'Unknown GLib exception while trying to '
+                        'mount device: %(message)s')
+                        % {'message': str(e)})
             except Exception, e:
-                raise TailsInstallerError(_("Unable to mount device: %(message)s")
-                                     % {'message': str(e)})
+                raise TailsInstallerError(_(
+                    "Unable to mount device: %(message)s")
+                    % {'message': str(e)})
 
             # Get the new mount point
             if not mount:
@@ -800,7 +837,8 @@ class LinuxTailsInstallerCreator(TailsInstallerCreator):
                     arg_options=GLib.Variant('a{sv}', None),
                     cancellable=None)
         self.drive['mount'] = None
-        if not self.opts.partition and self.dest is not None and os.path.exists(self.dest):
+        if not self.opts.partition and self.dest is not None \
+           and os.path.exists(self.dest):
             self.log.error(_("Mount %s exists after unmounting") % self.dest)
         self.dest = None
         # Sometimes the device is still considered as busy by the kernel
@@ -821,32 +859,32 @@ class LinuxTailsInstallerCreator(TailsInstallerCreator):
         self.log.debug("Creating partition table")
         # Use udisks instead of plain sgdisk will allow unprivileged users
         # to get a refreshed partition table from the kernel
-        try:
-            self._get_object().props.block.call_format_sync(
+        for attempt in [1, 2]:
+            try:
+                self._get_object().props.block.call_format_sync(
                     'gpt',
                     arg_options=GLib.Variant('a{sv}', None),
                     cancellable=None)
-        except GLib.Error as e:
-            # XXX: sometimes retrying fails as well
-            # https://bugs.freedesktop.org/show_bug.cgi?id=76178
-            if ('GDBus.Error:org.freedesktop.UDisks2.Error.Failed' in e.message and
+            except GLib.Error as e:
+                if attempt > 1:
+                    raise
+                # XXX: sometimes retrying fails as well
+                # https://bugs.freedesktop.org/show_bug.cgi?id=76178
+                if ('GDBus.Error:org.freedesktop.UDisks2.Error.Failed' in e.message and
                     'Error synchronizing after initial wipe' in e.message):
-                self.log.debug("Failed to synchronize. Trying again, which usually solves the issue. Error was: %s" % e.message)
-                self.flush_buffers(silent=True)
-                time.sleep(5)
-                self._get_object().props.block.call_format_sync(
-                        'gpt',
-                        arg_options=GLib.Variant('a{sv}', None),
-                        cancellable=None)
-            else:
-                raise
+                    self.log.debug("Failed to synchronize. Trying again, which usually solves the issue. Error was: %s" % e.message)
+                    self.flush_buffers(silent=True)
+                    time.sleep(5)
 
         self.log.debug("Creating partition")
         partition_table = self._get_object().props.partition_table
         try:
             partition_table.call_create_partition_sync(
                     arg_offset=0,
-                    arg_size=self.system_partition_size * 2**20,
+                    arg_size=self.system_partition_size(
+                        self.drive['parent_size']
+                        if self.drive['parent_size']
+                        else self.drive['size']),
                     arg_type=ESP_GUID,
                     arg_name=self.label,
                     arg_options=GLib.Variant('a{sv}', None),
@@ -867,13 +905,6 @@ class LinuxTailsInstallerCreator(TailsInstallerCreator):
         self.rescan_block_device(self._get_object().props.block)
         system_partition = self.first_partition(self.drive['udi'])
 
-        # Sets the partition type that is not set by call_create_partition_sync...
-        # because it is not implemented in UDisks as of version 2.1.5 (see
-        # http://cgit.freedesktop.org/udisks/tree/src/udiskslinuxpartitiontable.c?id=a66691c3#n630)
-        #
-        # XXX: sometimes fails (https://labs.riseup.net/code/issues/10987)
-        system_partition.call_set_type_sync(ESP_GUID, GLib.Variant('a{sv}', None))
-
         # Get a fresh system_partition object, otherwise
         # _set_partition_flags sometimes fails with
         # "GDBus.Error:org.freedesktop.DBus.Error.UnknownMethod: No
@@ -882,26 +913,22 @@ class LinuxTailsInstallerCreator(TailsInstallerCreator):
         self.rescan_block_device(self._get_object().props.block)
         system_partition = self.first_partition(self.drive['udi'])
 
+        # XXX: This resets the partition type for some reason
+        # (https://github.com/storaged-project/udisks/issues/418)
         # XXX: sometimes fails (https://labs.riseup.net/code/issues/10987)
         self._set_partition_flags(system_partition, SYSTEM_PARTITION_FLAGS)
 
+        # _set_partition_flags resets the partition type with udisks2 2.7.3-4,
+        # so let's set the right one again
+        # XXX: sometimes fails (https://labs.riseup.net/code/issues/10987)
+        system_partition.call_set_type_sync(ESP_GUID, GLib.Variant('a{sv}', None))
+
         # Give the system some more time to recognize the updated
         # partition, otherwise sometimes later on, when
         # switch_drive_to_system_partition is called, it calls
         # _set_drive, that fails with "Cannot find device /dev/sda1".
         self.rescan_block_device(self._get_object().props.block)
 
-    def update_system_partition_properties(self):
-        self.log.info(_('Updating properties of system partition %(system_partition)s') % {
-            'system_partition': self.drive['device']
-        })
-
-        system_partition = self._get_object().props.partition
-        system_partition.call_set_type_sync(ESP_GUID, GLib.Variant('a{sv}', None))
-        system_partition.call_set_name_sync(self.label, GLib.Variant('a{sv}', None))
-
-        self._set_partition_flags(system_partition, SYSTEM_PARTITION_FLAGS)
-
     def is_partition_GPT(self, drive=None):
         # Check if the partition scheme is GPT
         if drive:
@@ -909,7 +936,11 @@ class LinuxTailsInstallerCreator(TailsInstallerCreator):
         else:
             obj = self._get_object()
 
-        if not obj.props.partition :
+        # First check if we actually have found the object
+        if obj is None:
+           return False
+        # and then if it has a partition
+        if not obj.props.partition:
             return False
 
         partition_table = obj.props.partition_table
@@ -920,25 +951,27 @@ class LinuxTailsInstallerCreator(TailsInstallerCreator):
         else:
             return False
 
-    def device_can_be_upgraded(self, drive=None):
-
+    def device_can_be_upgraded(self, device_data=None):
         # Checks that device already has Tails installed
+        if not device_data:
+            device = self.drive
+        else:
+            device = device_data
+        return not self.device_is_isohybrid(device) and self.is_partition_GPT(device) \
+               and device['fstype'] == 'vfat' and device['label'] == 'Tails'
+
+    def device_is_isohybrid(self, drive=None):
         if not drive:
             device = self.drive
         else:
             device = drive
-
-        if self.is_partition_GPT(device) and device['fstype'] == 'vfat' \
-           and device['label'] == 'Tails':
-            return True
-        else:
-            return False
+        return device['fstype'] == 'iso9660'
 
     def save_full_drive(self):
         self._full_drive = self.drives[self._drive]
 
     def switch_drive_to_system_partition(self):
-        full_drive_name  = self._full_drive['device']
+        full_drive_name = self._full_drive['device']
         append = False
         if full_drive_name.startswith('/dev/sd'):
             append = '1'
@@ -962,10 +995,10 @@ class LinuxTailsInstallerCreator(TailsInstallerCreator):
         if self.fstype not in self.valid_fstypes:
             if not self.fstype:
                 raise TailsInstallerError(_("Unknown filesystem.  Your device "
-                                     "may need to be reformatted."))
+                                            "may need to be reformatted."))
             else:
                 raise TailsInstallerError(_("Unsupported filesystem: %s" %
-                                     self.fstype))
+                                            self.fstype))
         if self.drive['label'] != self.label:
             self.log.info("Setting %(device)s label to %(label)s" %
                           {'device': self.drive['device'],
@@ -1013,8 +1046,9 @@ class LinuxTailsInstallerCreator(TailsInstallerCreator):
                         copied = True
                         break
                 if not copied:
-                    raise TailsInstallerError(_("Could not find the '%s' COM32 module")
-                                       % com32mod)
+                    raise TailsInstallerError(_(
+                        "Could not find the '%s' COM32 module")
+                        % com32mod)
 
         # Don't prompt about overwriting files from mtools (#491234)
         for ldlinux in [self.get_liveos_file_path(p, 'ldlinux.sys')
@@ -1029,7 +1063,8 @@ class LinuxTailsInstallerCreator(TailsInstallerCreator):
             syslinux_executable = 'syslinux';
             self.log.debug('Will use %s as the syslinux binary'
                            % syslinux_executable)
-            iso_syslinux = self.get_liveos_file_path('utils', 'linux', syslinux_executable)
+            iso_syslinux = self.get_liveos_file_path('utils', 'linux',
+                                                     syslinux_executable)
             tmpdir = tempfile.mkdtemp()
             tmp_syslinux = os.path.join(tmpdir, syslinux_executable)
             shutil.copy(iso_syslinux, tmp_syslinux)
@@ -1037,7 +1072,7 @@ class LinuxTailsInstallerCreator(TailsInstallerCreator):
                      os.stat(tmp_syslinux).st_mode | stat.S_IEXEC | stat.S_IXGRP | stat.S_IXOTH)
             self.flush_buffers()
             self.unmount_device()
-            self.popen('%s %s -d %s %s' %  (
+            self.popen('%s %s -d %s %s' % (
                     tmp_syslinux,
                     ' '.join(self.syslinux_options()),
                     'syslinux', self.drive['device']))
@@ -1045,9 +1080,10 @@ class LinuxTailsInstallerCreator(TailsInstallerCreator):
         else:
             self.flush_buffers()
             self.unmount_device()
-            self.popen('/usr/bin/pkexec /usr/bin/syslinux %s -d syslinux %s' % (
-                ' '.join(self.syslinux_options()),
-                self.drive['device']))
+            self.popen(
+                '/usr/bin/pkexec /usr/bin/syslinux %s -d syslinux %s' % (
+                    ' '.join(self.syslinux_options()),
+                    self.drive['device']))
 
     def get_free_bytes(self, device=None):
         """ Return the number of available bytes on our device """
@@ -1148,8 +1184,8 @@ class LinuxTailsInstallerCreator(TailsInstallerCreator):
         """ Return the PedDisk and partition of the selected device """
         import parted
         parent = self.drives[self._drive]['parent']
-        dev = parted.Device(path = parent)
-        disk = parted.Disk(device = dev)
+        dev = parted.Device(path=parent)
+        disk = parted.Disk(device=dev)
         for part in disk.partitions:
             if self._drive == "/dev/%s" %(part.getDeviceNodeName(),):
                 return disk, part
